==> unwanted_email_registration-1.0.0.tar.gz: unwanted_email_registration/src/Form/UnwantedEmailRegistrationConfigForm.php <==
<?php

namespace Drupal\unwanted_email_registration\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Class UnwantedEmailRegistrationConfigForm settings.
 */
class UnwantedEmailRegistrationConfigForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function __construct(ConfigFactoryInterface $config_factory) {
    parent::__construct($config_factory);
    $this->configFactory = $config_factory;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'unwanted_email_registration_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['unwanted_email_registration.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    // @todo description for All Fields
    $form = parent::buildForm($form, $form_state);
    $config = $this->config('unwanted_email_registration.settings');
    $form['unwanted_email_registration_settings'] = [
      '#type' => 'vertical_tabs',
    ];

    $form['unwanted_email_registration_settings']['settings'] = [
      '#type' => 'details',
      '#title' => $this->t('Settings'),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
      '#group' => 'unwanted_email_registration_settings',
      '#weight' => 0,
    ];

    $form['unwanted_email_registration_settings']['settings']['filter_chars'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Filter Chars'),
      '#default_value' => $config->get('filter_chars'),
      '#required' => TRUE,
      '#description' => $this->t('Characters to check for and eliminate when doing comparisons of addresses.'),
    ];

    $form['unwanted_email_registration_settings']['settings']['email_domains'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Domains'),
      '#default_value' => $config->get('email_domains'),
      '#required' => TRUE,
      '#description' => $this->t('Characters to prevent email registration with. Separated by comma.'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);
    $config = $this->configFactory->getEditable('unwanted_email_registration.settings');
    $config->set('filter_chars', $form_state->getValue('filter_chars'))->save();
    $config->set('email_domains', $form_state->getValue('email_domains'))->save();
    $this->config('unwanted_email_registration.settings')->save();
  }

}

==> unwanted_email_registration-1.0.1.tar.gz: unwanted_email_registration/src/Form/UnwantedEmailRegistrationConfigForm.php <==
<?php

namespace Drupal\unwanted_email_registration\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Class UnwantedEmailRegistrationConfigForm settings.
 */
class UnwantedEmailRegistrationConfigForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function __construct(ConfigFactoryInterface $config_factory) {
    parent::__construct($config_factory);
    $this->configFactory = $config_factory;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'unwanted_email_registration_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['unwanted_email_registration.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    // @todo description for All Fields
    $form = parent::buildForm($form, $form_state);
    $config = $this->config('unwanted_email_registration.settings');
    $form['unwanted_email_registration_settings'] = [
      '#type' => 'vertical_tabs',
    ];

    $form['unwanted_email_registration_settings']['settings'] = [
      '#type' => 'details',
      '#title' => $this->t('Settings'),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
      '#group' => 'unwanted_email_registration_settings',
      '#weight' => 0,
    ];

    $form['unwanted_email_registration_settings']['settings']['filter_chars'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Filter Chars'),
      '#default_value' => $config->get('filter_chars'),
      '#required' => TRUE,
      '#description' => $this->t('Characters to prevent email registration with. Separated by comma.'),
    ];

    $form['unwanted_email_registration_settings']['settings']['email_domains'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Domains'),
      '#default_value' => $config->get('email_domains'),
      '#required' => TRUE,
      '#description' => $this->t('Enter domain names of email addresses to apply this rule. One domain on each line.'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);
    $config = $this->configFactory->getEditable('unwanted_email_registration.settings');
    $config->set('filter_chars', $form_state->getValue('filter_chars'))->save();
    $config->set('email_domains', $form_state->getValue('email_domains'))->save();
    $this->config('unwanted_email_registration.settings')->save();
  }

}
